
Access to any master secret must be protected from unauthorised access
-------

**Description:**

Access to any master secret must be protected from unauthorised access in order to protect 
the integrity and the confidentiality of the data.


**Solution:**

Whenever sensitive data is stored on the server you should consider storing this data in a 
separate folder with permission rules in order to prevent unauthorised 
users to read these files. It is also highly recommended to encrypt/hash the password in 
order to enforce higher security.

	